Skip to contents

Convenience function that joins enrolments to students, giving you a combined tibble with student contact details alongside each enrolment.

Usage

selma_join_students(enrolments, students)

Arguments

enrolments

A tibble from selma_enrolments().

students

A tibble from selma_students().

Value

A tibble with enrolment and student columns joined.

Examples

if (FALSE) { # \dontrun{
con <- selma_connect()
enrolments <- selma_enrolments(con)
students <- selma_students(con)
student_enrolments <- selma_join_students(enrolments, students)
} # }