Retrieves notes and event records linked to students and enrolments. Notes include pastoral care records, meeting notes, and other student-related documentation.
Usage
selma_notes(
con = NULL,
cache = FALSE,
cache_dir = "selma_cache",
cache_hours = 24,
items_per_page = 100L,
.progress = TRUE
)Arguments
- con
A
selma_connectionobject fromselma_connect(), orNULL(default) to use the stored connection.- cache
If
TRUE, use RDS caching (defaultFALSE).- cache_dir
Directory for cache files (default
"selma_cache").- cache_hours
Hours before cache is considered stale (default 24).
- items_per_page
Items per API page (default 100).
- .progress
Show progress messages (default
TRUE).
Value
A tibble of note/event records with columns including noteid,
student_id, enrolmentid, notetype, notearea, note1, and
confidential.
Examples
if (FALSE) { # \dontrun{
con <- selma_connect()
notes <- selma_notes(con)
# Notes for a specific student
student_notes <- notes |>
dplyr::filter(student_id == "123")
} # }