Retrieves the custom field data stored against a specific student.
Examples
if (FALSE) { # \dontrun{
selma_connect()
selma_student_custom_fields("123")
} # }
Retrieves the custom field data stored against a specific student.
if (FALSE) { # \dontrun{
selma_connect()
selma_student_custom_fields("123")
} # }